#!groovy

def main() {
    String gitUrl = "${env.GERRIT_SCHEME}://${env.GERRIT_HOST}:${env.GERRIT_PORT}/${env.GERRIT_PROJECT}"
    String gitRef = env.REFSPEC
    String artInfraNamespace = 'binary-dev-local/infra'
    String artCacheFile = "${env.CI_NAME}.jeepyb.zip"
    String artCacheUrl = "${env.ARTIFACTORY_URL}/artifactory/${artInfraNamespace}/${artCacheFile}"
    String artCredential = env.ART_CREDENTIALS_ID
    String cacheHome = '.workspace'
    def response

    stage('SCM checkout') {
        if (env.MAINTAIN_MODE.toLowerCase() == 'false') {
            checkout \
                $class: 'GitSCM',
                branches: [[
                    name: 'FETCH_HEAD'
                ]],
                userRemoteConfigs: [[
                    url: gitUrl,
                    refspec: gitRef,
                    credentialsId: env.GIT_CREDENTIALS_ID
                ]],
                extensions: [[
                    $class: 'WipeWorkspace'
                ]]
        }
    }

    /*stage('Get jeepyb cache') {
        dir(cacheHome) {
            response = httpRequest \
                url: artCacheUrl,
                authentication: artCredential,
                httpMode: 'GET',
                outputFile: artCacheFile,
                validResponseCodes: '100:399,404'
            if (response.status != 404) {
               unzip \
                   zipFile: artCacheFile
            }
        }
    }*/

    stage("Jeepyb-${TOX_ENV}") {
        if (env.MAINTAIN_MODE.toLowerCase() == 'false') {
            sshagent([env.JEEPYB_CREDENTIALS_ID]) {
                withEnv([
                    "HOME=${cacheHome}",
                    'GIT_SSH_VARIANT=ssh'
                ]) {
                    sh 'tox -v -e ${TOX_ENV}'
                }
            }
        } else {
            input \
                message: 'Sleeping for maintainance'
        }
    }
    /*stage('Save jeepyb cache') {
        dir(cacheHome) {
            sh "rm -f ${artCacheFile}"
            zip \
                zipFile: artCacheFile,
                glob: 'cache/project.cache'
            response = httpRequest \
                url: artCacheUrl,
                authentication: artCredential,
                httpMode: 'PUT',
                multipartName: 'file',
                uploadFile: artCacheFile
        }
    }*/
}

String podTpl = """
    apiVersion: "v1"
    kind: "Pod"
    spec:
      securityContext:
        runAsUser: 1000
      containers:
      - name: "main"
        image: "${env.DOCKER_IMAGE}"
        command:
        - "cat"
        securityContext:
          privileged: false
        tty: true
"""
podTemplate(
        cloud: env.K8S_CLUSTER,
        yaml: podTpl,
        showRawYaml: false
    ) {
        node(POD_LABEL) {
        container('main') {
            main()
        }
    }
}
